# maue-parser
parser for MAÜ files, which are created and forwarded in rhineland-palatinate by emergency control centers for the transmission of alerting data

Parser für MAÜ Files, welche von den Leitstellen in Rheinland Pfalz zur Alarmdatenweitergabe genutzt werden.
